/*
 * This file is part of SEMP.
 *
 * SEMP is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEMP is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with SEMP. If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2009, 2010, 2011, 2012 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */

#ifndef DIRECTSHOW_H
#define DIRECTSHOW_H

#include <windows.h>
#include "../stdafx.h"
#include "OSD.h"
#include "Utils.h"
#include "../se/EffectManager.h"

// this needs to be done as specified in the MSDN
#pragma include_alias( "dxtrans.h", "qedit.h" )
#define __IDxtCompositor_INTERFACE_DEFINED__
#define __IDxtAlphaSetter_INTERFACE_DEFINED__
#define __IDxtJpeg_INTERFACE_DEFINED__
#define __IDxtKey_INTERFACE_DEFINED__
#include "qedit.h"

class DirectShow
{
private:
	HRESULT GetUnconnectedPin(IBaseFilter *pFilter, PIN_DIRECTION PinDir, IPin **ppPin);
	HRESULT ConnectFilters(IGraphBuilder *pGraph, IPin *pOut, IBaseFilter *pDest);
	HRESULT ConnectFilters(IGraphBuilder *pGraph, IBaseFilter *pSrc, IBaseFilter *pDest);
	HRESULT InitCaptureGraphBuilder(IGraphBuilder **ppGraph, ICaptureGraphBuilder2 **ppBuild);
	HRESULT InitWindowlessVMR(HWND hwndApp, IGraphBuilder* pGraph, IVMRWindowlessControl** ppWc);

public:
	DirectShow(OSD* osd, bool debug);
	~DirectShow();
	int InitDirectShow(HWND appWindow, bool autoColor, bool storeBMP, bool disableMMX);
	void CleanUpDirectShow();
	void OnGraphEvent();
	int UpdateVolume(long volume);
	int CreateGraph(char* filename, char* executeDir, long lVolume, EffectManager* effectManager);
	IVMRWindowlessControl* GetVMRWindowlessControl();
	IGraphBuilder* GetGraphBuilder();
	IMediaControl* GetMediaControl();
	IMediaEventEx* GetMediaEvent();
	IMediaPosition* GetMediaPosition();
	IBasicAudio* GetBasicAudio();
	IMediaSeeking* GetMediaSeek();
	ISampleGrabber* GetSampleGrabber();
	AM_MEDIA_TYPE GetAMMediaType();
	VIDEOINFOHEADER *GetVideoInfoHeader();

private:
	// DirectShow interfaces
	IGraphBuilder*	g_pGraphBuilder;
	IMediaControl*	g_pMediaControl;
	IMediaEventEx*	g_pMediaEvent;
	IMediaPosition*	g_pMediaPosition;
	IBasicAudio* g_pBasicAudio;
	IMediaSeeking* g_pMediaSeek;
	IVMRWindowlessControl* g_pWindowlessControl;
	IBaseFilter* g_pWindowlessFilter;
	IBaseFilter* g_pSourceFilter;
	ICaptureGraphBuilder2* g_pCaptureGraph;
	bool g_bDebug;
	OSD* g_pOSD;
	ISampleGrabber* g_pSampleGrabber;
	IBaseFilter* g_pGrabberFilter;
	bool g_bAutoColor;
	bool g_bDisableMMX;
	bool g_bStoreBMP;
	AM_MEDIA_TYPE mt;
	VIDEOINFOHEADER *pVih;
};

#endif
