/*
 * This file is part of SEMP.
 *
 * SEMP is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEMP is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with SEMP. If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2009, 2010, 2011, 2012 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */

#include "Element.h"

/**
Constructor
*/
Element::Element()
{
	l_time = -1.0;
	i_type = 0;
	played_time = -1.0;
}

/**
Destructor
*/
Element::~Element()
{
}

/**
Method for setting the time when the effect was played
\param time of the effect playback
*/
void Element::SetPlayedTime(double time)
{
	played_time = time;
}

/**
Method for retrieving the played time of an effect
\return time when the effect was played
*/
double Element::GetPlayedTime()
{
	return played_time;
}

/**
Method for retrieving the value of an identifer
\param identifier from which the value should be retrieved
\return string with the value
*/
std::string Element::GetValue(std::string identifier)
{
	std::map<std::string, std::string>::const_iterator foundElement;

	foundElement = m_value.find(identifier);
	if (foundElement != m_value.end())
		return foundElement->second;
	else
		return "";
}

/**
Method for retrieving all values of an element
\return map with all identifiers and values
*/
std::map<std::string, std::string> Element::GetValues()
{
	return m_value;
}

/**
Method for adding an identifier and value
\param identifier to be added
\param value to be assigned to identifier
*/
void Element::AddValue(std::string identifier, std::string value)
{
	m_value[identifier] = value;
}

/**
Method for retrieving the time of the element
\return time
*/
double Element::GetTime() const
{
	return l_time;
}

/**
Method for setting the time of an element
\param time to set
*/
void Element::SetTime(double time)
{
	l_time = time;
}

/**
Method for setting the type of an element
\param type of the element
*/
void Element::SetType(int type)
{
	i_type = type;
}

/**
Method for retrieving the type of an element
\return type of the element
*/
int Element::GetType()
{
	return i_type;
}

/**
Method for printing information of an element
*/
void Element::Print()
{
	printf("type: %i\ntime: %f\n", i_type, l_time);
	for (std::map<std::string, std::string>::const_iterator it = m_value.begin(); it != m_value.end(); ++it)
		std::cout << it->first << ":" << it->second << ";  ";

	std::cout << std::endl;
}
