/*
 * This file is part of SEMP.
 *
 * SEMP is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEMP is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with SEMP. If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2009, 2010, 2011, 2012 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */

#include "Light.h"

#if __USEAMBX__
/**
Constructor
\param light with the amBX light
*/
Light::Light(IamBX_Light* light)
{
	bLightFade = false;
	lightFadeTime = -1.0;
	lightEffectDifference = -1.0;
	lightDuration = -1.0;
	lightIntensity = -1.0;
	lightOldIntensityValue = 0.0;
	lightPTS = -1.0;
	m_light = light;
}

/**
Destructor
*/
Light::~Light()
{
}

/**
Method for reseting the light
*/
void Light::ResetLight()
{
	bLightFade = false;
	lightFadeTime = -1.0;
	lightDuration = -1.0;
	lightIntensity = -1.0;
	lightOldIntensityValue = 0.0;
	lightEffectDifference = -1.0;
	lightPTS = -1.0;
}

/**
Method for determining if fading is active
\return true if fade is active else false
*/
bool Light::IsFadeActive()
{
	return bLightFade;
}

/**
Getter for the timestamp
\return timestamp
*/
double Light::GetPTS()
{
	return lightPTS;
}

/**
Setter for the timestamp
\param time with the timestamp
*/
void Light::SetPTS(double time)
{
	lightPTS = time;
}

/**
Setter for activating fading
\param activate true for activating else false
*/
void Light::ActivateFade(bool activate)
{
	bLightFade = activate;
}

/**
Getter for the duration of the effect
\return duration
*/
double Light::GetDuration()
{
	return lightDuration;
}

/**
Getter for the intensity
\return intensity
*/
double Light::GetIntensity()
{
	return lightIntensity;
}

/**
Getter for the fading time
\return fading time
*/
double Light::GetFadeTime()
{
	return lightFadeTime;
}

/**
Setter for the intensity
\param intensity
*/
void Light::SetIntensity(double intensity)
{
	lightIntensity = intensity;
}

/**
Setter for the effect duration
\param duration
*/
void Light::SetDuration(double duration)
{
	lightDuration = duration;
}

/**
Setter for the fading time
\param fadeTime with the fading time
*/
void Light::SetFadeTime(double fadeTime)
{
	lightFadeTime = fadeTime;
}

/**
Getter for retrieving the light
\return amBX light
*/
IamBX_Light *Light::GetLight()
{
	return m_light;
}

/**
Setter for the light color
\param r red value
\param g green value
\param b blue value
*/
void Light::SetLightColor(int r, int g, int b)
{
	lightColor[0] = r;
	lightColor[1] = g;
	lightColor[2] = b;
}

/**
Getter for the light color
\return light color array
*/
int *Light::GetLightColor()
{
	return lightColor;
}

/**
Setter for the effect difference
only used by fading
\param difference
*/
void Light::SetEffectDifference(double difference)
{
	lightEffectDifference = difference;
}

/**
Getter for the effect difference
\return effect difference
*/
double Light::GetEffectDifference()
{
	return lightEffectDifference;
}

/**
Setter for the old intensity
\param oldIntensity with the old intensity
*/
void Light::SetOldIntensityValue(double oldIntensity)
{
	lightOldIntensityValue = oldIntensity;
}

/**
Getter for the old intensity value
\return old intensity
*/
double Light::GetOldIntensityValue()
{
	return lightOldIntensityValue;
}
#endif
